# momi

momi (MOran Models for Inference) is a Python package that computes
the expected sample frequency spectrum (SFS), a statistic commonly used
in population genetics, and uses it to fit demographic history.

See the [documentation](http://momi2.readthedocs.io/en/latest/)
for installation instructions, tutorial, and API reference.

The preprint describing the method is:

Kamm, J.A., Terhorst, J., Durbin, R, and Song, Y.S. Efficiently inferring the demographic history of many populations with allele count data. ([bioRxiv](https://www.biorxiv.org/content/early/2018/03/23/287268))


